/***********************************************************************************************************************
 *
 * SolidBlue - open source safe data
 * Copyright (C) 2011-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://solidblue.java.net
 * SCM: https://bitbucket.org/tidalwave/solidblue-src
 *
 **********************************************************************************************************************/
package it.tidalwave.netbeans.lookandfeel.ui.quaqua;

import java.awt.Component;
import java.awt.Container;
import java.awt.GridBagConstraints;
import javax.swing.JComponent;
import javax.swing.UIManager;
import ch.randelshofer.quaqua.QuaquaOptionPaneUI;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id$
 *
 ******************************************************************************/
public class BMQuaquaOptionPaneUI extends QuaquaOptionPaneUI
  {
    /** A CSS compliant with Apple Human Interface Guideline. */
    private static final String CSS = "<head>"+
     "<style type=\"text/css\">"+
    "b { font: 13pt \"Lucida Grande\" }"+
    "p { font: 11pt \"Lucida Grande\"; margin-top: 8px }"+
    "</style>"+
    "</head>";
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    public static BMQuaquaOptionPaneUI createUI (JComponent component) 
      {
        return new BMQuaquaOptionPaneUI();
      }    
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    protected void addMessageComponents (Container container,
                                         GridBagConstraints cons,
                                         Object msg, 
                                         int maxll,
                                         boolean internallyCreated)  
      {
        if (msg instanceof String)
          {
            String string = (String)msg;  
            
            if (string.toLowerCase().startsWith("<html>") && !string.toLowerCase().startsWith("<html><head>"))
              {
                msg = "<html>" + CSS + string.substring(6);
              }
          }
        
        else if (msg instanceof JComponent)
          {
            ((JComponent)msg).setOpaque(true);
            ((JComponent)msg).setBackground(UIManager.getColor("OptionPane.background"));
          }
        
        super.addMessageComponents(container, cons, msg, maxll, internallyCreated);
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    protected Container createButtonArea() 
      {
        Container c = super.createButtonArea();
        
        if (c instanceof JComponent)
          {
            ((JComponent)c).setOpaque(false);
          }
        
        return c;
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    protected void addButtonComponents (Container container, Object[] buttons, int initialIndex) 
      {
        super.addButtonComponents(container, buttons, initialIndex);
        
        for (final Component c : container.getComponents())
          {
            if (c instanceof JComponent)
              {
                ((JComponent)c).setOpaque(false);
              }
          }
      }
}
